<template>
  <div class="container mx-auto px-4 py-8">
    <div class="bg-white rounded-lg shadow-sm p-6 mb-6 border border-gray-100">
      <div class="flex justify-between items-center mb-6">
        <h3 class="text-lg font-medium">Knowledge Base Management</h3>
        <button @click="openModal()" class="px-4 py-2 bg-green-700 text-white rounded-md hover:bg-green-800 flex items-center">
          <span class="mr-1">+</span> Add Knowledge
        </button>
      </div>

      <!-- Knowledge Base Table -->
      <div class="overflow-x-auto">
        <table class="min-w-full divide-y divide-gray-200">
          <thead>
            <tr>
              <th class="px-6 py-3 bg-gray-50 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Title</th>
              <th class="px-6 py-3 bg-gray-50 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Category</th>
              <th class="px-6 py-3 bg-gray-50 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
              <th class="px-6 py-3 bg-gray-50 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Created</th>
              <th class="px-6 py-3 bg-gray-50 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Last Updated</th>
              <th class="px-6 py-3 bg-gray-50 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
            </tr>
          </thead>
          <tbody class="bg-white divide-y divide-gray-200">
            <tr v-for="item in knowledgeBase" :key="item.id">
              <td class="px-6 py-4 whitespace-nowrap">{{ item.title }}</td>
              <td class="px-6 py-4 whitespace-nowrap">{{ item.category }}</td>
              <td class="px-6 py-4 whitespace-nowrap">
                <span :class="{
                  'px-2 py-1 text-xs rounded-full': true,
                  'bg-green-100 text-green-800': item.status === 'active',
                  'bg-yellow-100 text-yellow-800': item.status === 'draft',
                  'bg-red-100 text-red-800': item.status === 'inactive'
                }">
                  {{ getStatusText(item.status) }}
                </span>
              </td>
              <td class="px-6 py-4 whitespace-nowrap">{{ formatDate(item.created_at) }}</td>
              <td class="px-6 py-4 whitespace-nowrap">{{ formatDate(item.updated_at) }}</td>
              <td class="px-6 py-4 whitespace-nowrap">
                <button @click="openModal(item)" class="text-blue-600 hover:text-blue-900 mr-3">Edit</button>
                <button @click="deleteItem(item.id)" class="text-red-600 hover:text-red-900">Delete</button>
              </td>
            </tr>
            <tr v-if="knowledgeBase.length === 0">
              <td colspan="6" class="px-6 py-4 text-center text-gray-500">
                No knowledge base items found
              </td>
            </tr>
          </tbody>
        </table>
      </div>
    </div>

    <!-- Create/Edit Modal -->
    <KnowledgeBaseModal
      :showModal="showModal"
      :form="form"
      :isEditing="isEditing"
      @close="closeModal"
      @submitForm="submitForm"
    />
  </div>
</template>

<script>
import { ref, onMounted } from 'vue';
import { useForm } from '@inertiajs/vue3';
import KnowledgeBaseModal from './KnowledgeBaseModal.vue';

export default {
  components: {
    KnowledgeBaseModal
  },
  
  props: {
    knowledgeBase: {
      type: Array,
      default: () => []
    }
  },
  
  setup(props) {
    const showModal = ref(false);
    const isEditing = ref(false);
    const form = ref({
      title: '',
      content: '',
      category: '',
      status: 'active'
    });

    const openModal = (item = null) => {
      if (item) {
        form.value = { ...item };
        isEditing.value = true;
      } else {
        form.value = {
          title: '',
          content: '',
          category: '',
          status: 'active'
        };
        isEditing.value = false;
      }
      showModal.value = true;
    };

    const closeModal = () => {
      showModal.value = false;
      form.value = {
        title: '',
        content: '',
        category: '',
        status: 'active'
      };
      isEditing.value = false;
    };

    const submitForm = () => {
      const formData = useForm(form.value);
      
      if (isEditing.value) {
        formData.put(`/knowledge-base/${form.value.id}`, {
          onSuccess: () => {
            closeModal();
          }
        });
      } else {
        formData.post('/knowledge-base', {
          onSuccess: () => {
            closeModal();
          }
        });
      }
    };

    const deleteItem = (id) => {
      if (confirm('Are you sure you want to delete this knowledge base item?')) {
        const formData = useForm({});
        formData.delete(`/knowledge-base/${id}`);
      }
    };

    const getStatusText = (status) => {
      const statusMap = {
        active: 'Active',
        draft: 'Draft',
        inactive: 'Inactive'
      };
      return statusMap[status] || status;
    };

    const formatDate = (date) => {
      return new Date(date).toLocaleString();
    };

    return {
      showModal,
      isEditing,
      form,
      openModal,
      closeModal,
      submitForm,
      deleteItem,
      getStatusText,
      formatDate
    };
  }
};
</script>
